;Cube Conquest (Working Title)
;------------------------------------------------------
;$Id: cubeconq.s,v 1.1.2.6 2002/08/18 01:46:07 Billy Exp $
;------------------------------------------------------
	processor 6502
    include "vcs.h"
;color defines
GRAY		=	$00
GOLD		=	$10
ORANGE		=	$20
BRT_ORANGE	=	$30
PINK		=	$40
PURPLE		=	$50
PURPLE_BLUE	=	$70
BLUE		=	$80
GREEN		=	$C0
LT_ORANGE	=	$F0

LUM1		= 	$00	
LUM2		=	$02
LUM3		= 	$04	
LUM4		= 	$06	
LUM5		= 	$08	
LUM6		= 	$0a	
LUM7		= 	$0c	
LUM8		=	$0e

LIGHTBLUE	=	BLUE | LUM1
LIGHTPINK	= 	PINK | LUM1

LIGHTGRAY	=	GRAY | LUM1
BLACK		= 	GRAY | LUM1
WHITE		=	$FF

MEDIUMRED	=	BRT_ORANGE | LUM3
MEDIUMGREEN	=	GREEN | LUM4

P0COLOR		=	MEDIUMRED
P1COLOR		=	MEDIUMGREEN



;Ram variables
	        SEG.U   variables
	       	org $80
	        
interlaced	ds	1
	        
framenum	ds	1

xpos0		ds	1
xpos1		ds	1

rand0		ds	1			;16 bit random number (random routines in common.s)
rand1		ds	1

delay_switch	ds	1		;used to delay switch checking
TEMP
temp0		ds	1
temp1		ds	1
temp2		ds	1
temp3		ds	1

	SEG code

	org	$f000
	include "common.s"				;common subs
	include	"FC_position.s"

;Setup stuff
start
	sei             ;clear interupts
	cld             ;set to non-BCD mode
    
;Clear all memory except $ff/$1ff - Stack end
	lda #0
clear
	sta $ff,x		;x still has $ff in it
	dex
	bne clear		;x comes out with 0

main_game

normal_repeat				;repeat point
	
	lda	#$FF				;start interlaced
	sta interlaced

;set player numbers to triple
	lda	#$06
	sta	NUSIZ0
	sta	NUSIZ1

;setup the missiles
	lda	#$02
	sta	RESMP0		;lock the missiles to the players (and disable)
	sta	RESMP1

;set background
	lda #BLACK
	sta COLUBK

;set framenum	
	lda	#2
	sta	framenum

frame
;Vertical sync
	dec	framenum
	
	lda	interlaced		;see if we are in interlaced mode
	beq	non_interlaced	

	lda framenum
	beq	even_sync	

non_interlaced			;entry point for non-interlaced
	;this is the vertical sync for the first field of an interlaced frame
	;or just a normal non-interlaced vertical sync
	lda #2
	sta WSYNC
	sta VSYNC ; Begin vertical sync.

	sta WSYNC ; First line of VSYNC
	sta WSYNC ; Second line of VSYNC.
	lda	#0
	sta WSYNC ; Third line of VSYNC.
	sta VSYNC ; (0)

	lda	#BLACK
	sta	COLUBK

	jmp done_sync
even_sync
	;this is the vertical sync for the second field of an interlaced fram
	sta WSYNC
	;need 40 cycles until the start of vertical sync
	
	;this style of loop delays 5*Y+1
	ldy	#7
even_sync_loop1
	dey		 
	bne	even_sync_loop1
	;36 cycles
	nop 		;38

	lda #2		;40
		
	sta VSYNC ; Begin vertical sync.
	sta WSYNC ; First line of VSYNC
	sta WSYNC ; Second line of VSYNC.

	sta WSYNC ; Third line of VSYNC.
	;need 33 cycles until the end of VSYNC

	;this style of loop delays 5*Y+1
	ldy	#6
even_sync_loop2
	dey		 
	bne	even_sync_loop2
	;31 cycles		
	lda #0	;33
	sta VSYNC 

done_sync

	LDA #40		;timer for 34 lines of blanking
	STA TIM64T

	lda	#22		;starting x of sprites
	sta	xpos0
	lda	#38
	sta xpos1

;this contains the positioning routine, 4 scan lines 
	include "position_players.s"	
;wait for the vertical blank to end

	jsr wait_timer
	sta	WSYNC	;37th line of VBLANK

	sta	VBLANK   ;A comes back as zero, end vblank
	sta WSYNC
	sta WSYNC

;start visible area		
	ldy	#10			;wait ten lines to space it down some
	jsr wait_lines

	lda	#P0COLOR	;set up my player colors
	sta	COLUP0
	lda	#P1COLOR
	sta	COLUP1

;first draw some diagonal lines
	ldx #4			;x is used for an outer loop counter to draw the lines 4 times
	lda framenum 	;see which frame I'm on
	beq diags_even

diags_odd
diags_outer_odd
	lda	#$40
	ldy	#4			
diags_inner_odd
	sta WSYNC		
	sta	GRP0		
	sta GRP1
	lsr				;shift bit over twice
	lsr
	dey
	bne diags_inner_odd
	dex
	bne diags_outer_odd
	jmp done_diags	

diags_even	
diags_outer_even
	lda	#$80
	ldy	#4			
diags_inner_even
	sta WSYNC
	sta	GRP0
	sta GRP1
	lsr				;shift bit over twice
	lsr
	dey
	bne diags_inner_even
	dex
	bne diags_outer_even
done_diags
	
	sta WSYNC 		;end of 26th/beginning of 27th line
	lda	#0
	sta GRP0		;kill the graphics
	sta GRP1	

;now on 27th line
	ldy	#10			;space down 10 more lines
	jsr wait_lines
;now on 37th line

;now draw some space ships
	lda framenum	
	beq ships_even

ships_odd	
	ldx #14			;x is an index into the graphic
ships_odd_loop
	lda	spaceship,x
	sta WSYNC
	sta GRP0
	sta GRP1
	dex				;need every other line
	dex
	bpl ships_odd_loop	

	jmp done_ships

ships_even
	ldx #15	
ships_even_loop
	lda	spaceship,x
	sta WSYNC
	sta GRP0
	sta GRP1
	dex
	dex
	bpl ships_even_loop	
	
done_ships
		
	sta WSYNC	;end of 45th/beginning of 46th
	lda #0		;kill the graphics
	sta GRP0
	sta GRP1

;now on 46th line


	ldy #40
	jsr wait_lines
;now on 86th line
;now the demo as suggested by Glenn Saunders
	lda	framenum
	beq	even_demo
	
odd_demo
	lda	#MEDIUMRED
	sta	COLUBK	
	ldy #10
	jsr wait_lines
;now on line +10
	lda	#BLACK
	sta COLUBK
	ldy #5
	jsr wait_lines

;now on line +15
	lda	#MEDIUMRED
	sta	COLUBK	
	ldy #10
	jsr wait_lines
;now on line +25
	lda	#BLACK
	sta COLUBK
	ldy #5
	jsr wait_lines

;now on line +30
	lda	#BLACK
	sta	COLUBK	
	ldy #10
	jsr wait_lines
;now on line +40
	lda	#BLACK
	sta COLUBK
	ldy #5
	jsr wait_lines

;now on line +45
	lda	#MEDIUMRED
	sta	COLUBK	
	sta WSYNC
;now on line +46
	lda	#BLACK
	sta COLUBK
	ldy #5
	jsr wait_lines

;now on line +51
	lda	#MEDIUMGREEN
	sta	COLUBK	
	sta WSYNC
;now on line +52
	lda	#BLACK
	sta COLUBK
	ldy #5
	jsr wait_lines

;now on line +57
	lda	#MEDIUMRED
	sta	COLUBK	
	sta WSYNC
;now on line +58
	lda	#BLACK
	sta COLUBK
	ldy #5
	jsr wait_lines

;now on line +63
	lda	#MEDIUMGREEN
	sta	COLUBK	
	sta WSYNC

;now on line +64
	jmp end_demo	
	
even_demo
	lda	#MEDIUMGREEN
	sta	COLUBK	
	ldy #10
	jsr wait_lines
;now on line +10
	lda	#BLACK
	sta COLUBK
	ldy #5
	jsr wait_lines

;now on line +15
	lda	#BLACK
	sta	COLUBK	
	ldy #10
	jsr wait_lines
;now on line +25
	lda	#BLACK
	sta COLUBK
	ldy #5
	jsr wait_lines

;now on line +30
	lda	#MEDIUMGREEN
	sta	COLUBK	
	ldy #10
	jsr wait_lines
;now on line +40
	lda	#BLACK
	sta COLUBK
	ldy #5
	jsr wait_lines

;now on line +45
	lda	#MEDIUMRED
	sta	COLUBK	
	sta WSYNC
;now on line +46
	lda	#BLACK
	sta COLUBK
	ldy #5
	jsr wait_lines
;now on line +51
	lda	#MEDIUMGREEN
	sta	COLUBK	
	sta WSYNC
;now on line +52
	lda	#BLACK
	sta COLUBK
	ldy #12
	jsr wait_lines
;now on line +64
end_demo
	lda	#BLACK
	sta COLUBK

;now on line 150
	ldy	#42
	jsr wait_lines


;Overscan
	jsr start_Overscan	

	lda delay_switch
	bne	skip_switch_check
;check for reset
	lda SWCHB
	and	#1
	bne	no_reset
reset
	lda	#15				;insert a delay
	sta delay_switch
	
	jmp	main_game
no_reset

;check for select
	lda SWCHB
	and #$02
	bne no_select

	lda #$FF
	eor	interlaced
	sta interlaced
	
	lda	#15				;insert a delay
	sta delay_switch	
	
no_select
skip_switch_check

frame_done
;update framenum
	lda framenum
	bne no_update_framenum
	lda	#2
	sta framenum
no_update_framenum

;decrement delay_switch
	lda	delay_switch
	beq	no_dec_delay_switch
	dec delay_switch
no_dec_delay_switch
;wait for overscan to end
	jsr wait_timer
;wait_FF
;	lda INTIM		;timer ended?
;	bne	wait_FF

	jmp frame

;this packs graphics.c and drawit.s all the way down to the bottom, where all should work	
	org	$fcf1		
	include "graphics.s"

;make sure nothing gets put here so unmodified superchargers 
;can play the game
	org	$fff8
	ds	4
;Boot up points....

	org	$fffc
	dc.w	start                    ; Reset vector
    dc.w	start                    ; IRQ vector

;------------------------------------------------------
;$Log: cubeconq.s,v $
;Revision 1.1.2.6  2002/08/18 01:46:07  Billy
;not much...
;
;Revision 1.1.2.5  2002/08/17 04:58:44  Billy
;interleaving improved
;
;Revision 1.1.2.4  2002/08/16 04:14:11  Billy
;maybe interlacing works.
;
;Revision 1.1.2.3  2002/08/16 02:38:45  Billy
;submitted to stella list, ugly
;
;Revision 1.1.2.2  2002/08/14 02:25:56  Billy
;experiment with changing background color
;
;Revision 1.1.2.1  2002/08/14 01:11:49  Billy
;Playfield experiments
;
;------------------------------------------------------
